import  {
  select, 
  csv, 
  scaleLinear, 
  scalePoint, 
  max, 
  axisLeft, 
  axisBottom,
  format
} from 'd3';
const svg = select("svg");
const width = +svg.attr("width"),
      height = +svg.attr("height");

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 80, left: 200, bottom: 65, right: 40}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  	.nice()
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.5);
  
  const xAxisTickFormat = number => 
  	format('0.3s')(number)
  		.replace('G', 'B');
  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight)
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  const g = svg.append("g")
  	.attr("transform", `translate(${margin.left}, ${margin.top})`)
  const yAxisG = g.append("g").call(yAxis)
	yAxisG.selectAll(".domain")
  		.remove();
  	
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", `translate(0, ${innerHeight})`);
  xAxisG.selectAll(".domain").remove();
  
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr('y', 55)
  	.attr('x', innerWidth / 2)
  	.attr('fill', 'black')
  	.text("Population");
  
  g.selectAll("circle")
  	.data(data)
  	.enter().append("circle")
  	.attr("cy", d => yScale(yValue(d)))
  	.attr("cx", d => xScale(xValue(d)))
  	.attr("r", 10);
  svg.append("text")
  	.attr("y", 50)
  	.attr("x", width / 2)
  	.attr("text-anchor", "middle")
  	.text("Top 10 Most Populous Countries")
}

csv('data.csv')
	.then(
  data => {
    data.forEach(d => d.population = +d.population)
    render(data)
  })